#!/usr/bin/env node
'use strict';

const fs = require('fs-extra');
const path = require('path');
const cosmiconfig = require('cosmiconfig');
const explorer = cosmiconfig('encrypt');
const cli = require('meow')(
  `
  Usage:
    $ encrypt-html
  Options:
    --input, -i Path to the input file
    --output, -o The resulting output filename
    --password, -p
    --salt -s
  
  Options for password, and salt can also be provided via .encryptrc file or an encrypt property in package.json
`,
  {
    flags: {
      input: {
        type: 'string',
        alias: 'i',
      },
      output: {
        type: 'string',
        alias: 'o',
      },
      password: {
        type: 'string',
        alias: 'p',
      },
      salt: {
        type: 'string',
        alias: 's',
      },
    },
  }
);

function main() {
  let results = explorer.searchSync();
  let config = results ? { ...results.config, ...cli.flags } : cli.flags;

  // verify if input path is provided
  if (
    !config.input ||
    typeof config.input === 'boolean' ||
    !fs.existsSync(path.resolve(process.cwd(), config.input))
  ) {
    console.error('Cannot resolve input file');
    return;
  }

  // if output is provided, verify if it is a valid string
  if (config.output && typeof config.output === 'boolean') {
    console.error('Provide a correct output name');
    return;
  }

  // verify if we have password and salt
  if (!config.password) {
    console.error('Password is not provided');
    return;
  }

  if (!config.salt) {
    console.error('Salt is not provided');
    return;
  }

  let inputPath = path.resolve(process.cwd(), config.input);

  let html = fs.readFileSync(inputPath, 'utf8');

  const Encrypt = require('./encrypt');
  const encryptor = new Encrypt(config);

  const encode = encryptor.encrypt(html);

  // write to an output file
  // if output path or file is provided, use that instead
  // note that the output extension will be disregarded
  let outputPath;
  if (config.output) {
    outputPath = path.join(
      process.cwd(),
      config.output.replace(/\.[^/.]+$/, '')
    );
  } else {
    outputPath = inputPath.replace(/\.[^/.]+$/, '') + '_encrypted';
  }

  fs.outputFileSync(`${outputPath}.html`, encode);
  fs.outputFileSync(`${outputPath}.xbres`, encode);

  console.log('Encrypted results generated to:');
  console.log(`${outputPath}.html`);
  console.log(`${outputPath}.xbres`);
}

main();
